class

package
v0.4.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 20, 2022 License: BSD-3-Clause Imports: 2 Imported by: 0

Documentation

Index

Constants

const ByteCodeVersion uint16 = 0x0001

Constant for current Weblang bytecode version

const ClassType_Cms uint8 = 0x08

Weblang built-in class type cms

const ClassType_Controller uint8 = 0x02

Weblang built-in class type controller

const ClassType_Firewall uint8 = 0x09

Weblang built-in class type firewall

const ClassType_Model uint8 = 0x04

Weblang built-in class type model

const ClassType_Object uint8 = 0x00

Weblang build-in class type object

const ClassType_Repository uint8 = 0x05

Weblang built-in class type repository

const ClassType_Router uint8 = 0x03

Weblang built-in class type router

const ClassType_Server uint8 = 0x01

Weblang built-in class type server

const ClassType_Service uint8 = 0x06

Weblang built-in class type service

const ClassType_View uint8 = 0x07

Weblang built-in class type view

Variables

This section is empty.

Functions

This section is empty.

Types

type ClassHeader

type ClassHeader struct {
	FileFormatText      [8]byte  // First 8 bytes of file. It's contains "WEBLANG\x0f"
	ClassName           [80]byte // Class name (max 80 symbols)
	ClassType           uint8    // Class type: object, server, controller, router, model, repository, service and view
	ByteCodeVersion     uint16   // Version of bytecode file
	InstructionSetCount uint64   // Count of InstructionSet struct
	ClassMethodsCount   uint64   // Count of ClassMethodHeader struct
	AttributesCount     uint64   // Count of declared class atributes
	SourceCodeHash      [32]byte // Sha-256 hash of sourcecode file. For sourcefile changes detection
}

Header struct for Weblang bytecode class file. Binary data block size: 336 bytes

func (*ClassHeader) WriteHeader

func (header *ClassHeader) WriteHeader()

Write header data to struct. Use to prepare for write header struct to file

Directories

Path Synopsis

Jump to